@@ -13,7 +13,7 @@
 */
 #include "glite/jobid/cjobid.h"
 
-#ident "$Header: /cvs/jra1mw/org.glite.lb.common/interface/context.h,v 1.17 2012/05/16 07:50:54 mvocu Exp $"
+#ident "$Header$"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -73,6 +73,9 @@ typedef enum _edg_wll_ContextParam {
 	EDG_WLL_PARAM_LBPROXY_SERVE_SOCK,/**<  lbproxy serve socket path */
 	EDG_WLL_PARAM_LBPROXY_USER,	/**< user credentials when logging to L&B Proxy */
 	EDG_WLL_PARAM_JPREG_TMPDIR,		/**< maildir storage path */
+	EDG_WLL_PARAM_LOG_FILE_PREFIX,  /**< logging file prefix */
+	EDG_WLL_PARAM_LOG_IL_SOCK,      /**< interlogger socket path */
+	EDG_WLL_PARAM_LBPROXY_SERVERNAME,	/**< name and port of LB server running collocated with proxy */
 	EDG_WLL_PARAM__LAST,		/**< marker, LB internal use only */
 } edg_wll_ContextParam;
 
@@ -104,6 +107,10 @@ typedef enum _edg_wll_Source {
 	EDG_WLL_SOURCE_PBS_SMOM,
 	EDG_WLL_SOURCE_PBS_MOM,
 	EDG_WLL_SOURCE_PBS_SCHEDULER,
+	EDG_WLL_SOURCE_CLOUD_MANAGER,
+	EDG_WLL_SOURCE_VM_MANAGER,
+	EDG_WLL_SOURCE_VM_SYSTEM,
+
 	EDG_WLL_SOURCE__LAST		/* marker, for internal use only */
 } edg_wll_Source;
 
